### Easytrack python library [![pypi package](https://img.shields.io/pypi/v/python-easytrack)](https://pypi.org/project/python-easytrack/)

Boilperate module for importing everywhere in the backend side.
